==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0 - Timetracker\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Responsible"
: "Responsible"

, "without responsible"
: "without responsible"

, "Bookmark Timeaccount"
: "Bookmark Timeaccount"

, "Close Timeaccount"
: "Close Timeaccount"

, "timeframe"
: "timeframe"

, "summary"
: "summary"

, "Total Timesheets"
: "Total Timesheets"

, "Billable Timesheets"
: "Billable Timesheets"

, "Total Time"
: "Total Time"

, "Time of Billable Timesheets"
: "Time of Billable Timesheets"

, "Description"
: "Description"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: "Assign '{0}' Tag"

, "Export Timesheets"
: "Export Timesheets"

, "Export as ODS"
: "Export as ODS"

, "Export as CSV"
: "Export as CSV"

, "Export as ..."
: "Export as ..."

, "Timesheet, Timesheets"
: [
  "Timesheet"
 ,"Timesheets"

]
, "Accounting"
: "Accounting"

, "Timeaccount, Timeaccounts"
: [
  "Timeaccount"
 ,"Timeaccounts"

]
, "Failed"
: "Failed"

, "Could not save {0}."
: "Could not save {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Booking deadline for this Timeaccount has been exceeded."

, "Closed Timeaccount Warning!"
: "Closed Timeaccount Warning!"

, "The selected Time Account is already closed."
: "The selected Time Account is already closed."

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: "The selected Time Account is already closed. Do you wish to continue anyway?"

, "Contract"
: "Contract"

, "without contract"
: "without contract"

, "Add New Timeaccount"
: "Add New Timeaccount"

, "Unit"
: "Unit"

, "Unit Price"
: "Unit Price"

, "Factor"
: "Factor"

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "closed"

, "open"
: "open"

, "Cleared In"
: "Cleared In"

, "Cleared at"
: "Cleared at"

, "Cost Center"
: "Cost Center"

, "Responsible Person"
: "Responsible Person"

, "Timesheets are billable"
: "Timesheets are billable"

, "Invoice"
: "Invoice"

, "Time Account, Time Accounts"
: [
  "Time Account"
 ,"Time Accounts"

]
, "Number"
: "Number"

, "Title"
: "Title"

, "Access"
: "Access"

, "Permissions"
: "Permissions"

, "Time Account - Billed"
: "Time Account - Billed"

, "not yet billed"
: "not yet billed"

, "to bill"
: "to bill"

, "billed"
: "billed"

, "Time Account - Status"
: "Time Account - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  "Timeaccount Grant"
 ,"Timeaccount Grants"

]
, "Book Own"
: "Book Own"

, "The grant to add Timesheets to this Timeaccount"
: "The grant to add Timesheets to this Timeaccount"

, "View All"
: "View All"

, "The grant to view Timesheets of other users"
: "The grant to view Timesheets of other users"

, "Book All"
: "Book All"

, "The grant to add Timesheets for other users"
: "The grant to add Timesheets for other users"

, "Manage Clearing"
: "Manage Clearing"

, "The grant to manage clearing of Timesheets"
: "The grant to manage clearing of Timesheets"

, "Timeaccount Favorites"
: "Timeaccount Favorites"

, "Delete {0}, Delete {0}"
: [
  "Delete {0}"
 ,"Delete {0}"

]
, "Favorite"
: "Favorite"

, "Show closed"
: "Show closed"

, "Timesheets ODS export configuration"
: "Timesheets ODS export configuration"

, "Use this configuration for the timesheet ODS export."
: "Use this configuration for the timesheet ODS export."

, "A Tag which is available in context menu for fast assignment"
: "A Tag which is available in context menu for fast assignment"

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: "Quick Tag allows to simply assign a predefined tag by the context menu."

, "default"
: "default"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in Timetracker Application."
: "Enabled Features in Timetracker Application."

, "Timeaccount Bookmarks"
: "Timeaccount Bookmarks"

, "none"
: "none"

, "last week"
: "last week"

, "status to bill"
: "status to bill"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: "Add timeaccounts as favorite to speedup timesheet creation.)"

, "Price"
: "Price"

, "Cleared in"
: "Cleared in"

, "Billed"
: "Billed"

, "Booking deadline"
: "Booking deadline"

, "Accounting time factor"
: "Accounting time factor"

, "hour"
: "hour"

, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Time Account (Number - Title)"

, "Billable"
: "Billable"

, "Cleared"
: "Cleared"

, "Date"
: "Date"

, "Start time"
: "Start time"

, "End time"
: "End time"

, "Duration"
: "Duration"

, "Need for Clarification"
: "Need for Clarification"

, "Accounting time"
: "Accounting time"

, "Workingtime is cleared"
: "Workingtime is cleared"

, "Workingtime cleared in"
: "Workingtime cleared in"

, "Time Account closed"
: "Time Account closed"

, "Timetracker"
: "Timetracker"

, "Timeaccounts to bill"
: "Timeaccounts to bill"

, "Timeaccounts not yet billed"
: "Timeaccounts not yet billed"

, "Timeaccounts already billed"
: "Timeaccounts already billed"

, "My Timesheets today"
: "My Timesheets today"

, "My Timesheets this week"
: "My Timesheets this week"

, "My Timesheets last week"
: "My Timesheets last week"

, "My Timesheets this month"
: "My Timesheets this month"

, "My Timesheets last month"
: "My Timesheets last month"

, "Manage timeaccounts"
: "Manage timeaccounts"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Add, edit and delete timeaccounts (includes all timesheet grants)"

, "Add timeaccounts"
: "Add timeaccounts"

, "Manage shared timeaccount favorites"
: "Manage shared timeaccount favorites"

, "Create or update shared timeaccount favorites"
: "Create or update shared timeaccount favorites"

, "Manage shared timesheet favorites"
: "Manage shared timesheet favorites"

, "Create or update shared timesheet favorites"
: "Create or update shared timesheet favorites"

, "Timesheet"
: "Timesheet"

, "Timeaccount"
: "Timeaccount"

, "Time Account"
: "Time Account"

, "Timeaccount Grant"
: "Timeaccount Grant"

, "Delete {0}"
: "Delete {0}"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0 - Timetracker\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Responsible"
: "Responsible"

, "without responsible"
: "without responsible"

, "Bookmark Timeaccount"
: "Bookmark Timeaccount"

, "Close Timeaccount"
: "Close Timeaccount"

, "timeframe"
: "timeframe"

, "summary"
: "summary"

, "Total Timesheets"
: "Total Timesheets"

, "Billable Timesheets"
: "Billable Timesheets"

, "Total Time"
: "Total Time"

, "Time of Billable Timesheets"
: "Time of Billable Timesheets"

, "Description"
: "Description"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: "Assign '{0}' Tag"

, "Export Timesheets"
: "Export Timesheets"

, "Export as ODS"
: "Export as ODS"

, "Export as CSV"
: "Export as CSV"

, "Export as ..."
: "Export as ..."

, "Timesheet, Timesheets"
: [
  "Timesheet"
 ,"Timesheets"

]
, "Accounting"
: "Accounting"

, "Timeaccount, Timeaccounts"
: [
  "Timeaccount"
 ,"Timeaccounts"

]
, "Failed"
: "Failed"

, "Could not save {0}."
: "Could not save {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Booking deadline for this Timeaccount has been exceeded."

, "Closed Timeaccount Warning!"
: "Closed Timeaccount Warning!"

, "The selected Time Account is already closed."
: "The selected Time Account is already closed."

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: "The selected Time Account is already closed. Do you wish to continue anyway?"

, "Contract"
: "Contract"

, "without contract"
: "without contract"

, "Add New Timeaccount"
: "Add New Timeaccount"

, "Unit"
: "Unit"

, "Unit Price"
: "Unit Price"

, "Factor"
: "Factor"

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "closed"

, "open"
: "open"

, "Cleared In"
: "Cleared In"

, "Cleared at"
: "Cleared at"

, "Cost Center"
: "Cost Center"

, "Responsible Person"
: "Responsible Person"

, "Timesheets are billable"
: "Timesheets are billable"

, "Invoice"
: "Invoice"

, "Time Account, Time Accounts"
: [
  "Time Account"
 ,"Time Accounts"

]
, "Number"
: "Number"

, "Title"
: "Title"

, "Access"
: "Access"

, "Permissions"
: "Permissions"

, "Time Account - Billed"
: "Time Account - Billed"

, "not yet billed"
: "not yet billed"

, "to bill"
: "to bill"

, "billed"
: "billed"

, "Time Account - Status"
: "Time Account - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  "Timeaccount Grant"
 ,"Timeaccount Grants"

]
, "Book Own"
: "Book Own"

, "The grant to add Timesheets to this Timeaccount"
: "The grant to add Timesheets to this Timeaccount"

, "View All"
: "View All"

, "The grant to view Timesheets of other users"
: "The grant to view Timesheets of other users"

, "Book All"
: "Book All"

, "The grant to add Timesheets for other users"
: "The grant to add Timesheets for other users"

, "Manage Clearing"
: "Manage Clearing"

, "The grant to manage clearing of Timesheets"
: "The grant to manage clearing of Timesheets"

, "Timeaccount Favorites"
: "Timeaccount Favorites"

, "Delete {0}, Delete {0}"
: [
  "Delete {0}"
 ,"Delete {0}"

]
, "Favorite"
: "Favorite"

, "Show closed"
: "Show closed"

, "Timesheets ODS export configuration"
: "Timesheets ODS export configuration"

, "Use this configuration for the timesheet ODS export."
: "Use this configuration for the timesheet ODS export."

, "A Tag which is available in context menu for fast assignment"
: "A Tag which is available in context menu for fast assignment"

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: "Quick Tag allows to simply assign a predefined tag by the context menu."

, "default"
: "default"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in Timetracker Application."
: "Enabled Features in Timetracker Application."

, "Timeaccount Bookmarks"
: "Timeaccount Bookmarks"

, "none"
: "none"

, "last week"
: "last week"

, "status to bill"
: "status to bill"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: "Add timeaccounts as favorite to speedup timesheet creation.)"

, "Price"
: "Price"

, "Cleared in"
: "Cleared in"

, "Billed"
: "Billed"

, "Booking deadline"
: "Booking deadline"

, "Accounting time factor"
: "Accounting time factor"

, "Stream"
: "Stream"

, "hour"
: "hour"

, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Time Account (Number - Title)"

, "Project time billable"
: "Project time billable"

, "Project time billable (combined)"
: "Project time billable (combined)"

, "Billable"
: "Billable"

, "Project time cleared in"
: "Project time cleared in"

, "Project time Invoice"
: "Project time Invoice"

, "Project time is cleared"
: "Project time is cleared"

, "Projecttime cleared (combined)"
: "Projecttime cleared (combined)"

, "Date"
: "Date"

, "Start time"
: "Start time"

, "End time"
: "End time"

, "Duration"
: "Duration"

, "Need for Clarification"
: "Need for Clarification"

, "Accounting time"
: "Accounting time"

, "Workingtime is cleared"
: "Workingtime is cleared"

, "Workingtime cleared in"
: "Workingtime cleared in"

, "Timetracker"
: "Timetracker"

, "My Timesheets today"
: "My Timesheets today"

, "My Timesheets this week"
: "My Timesheets this week"

, "My Timesheets last week"
: "My Timesheets last week"

, "My Timesheets this month"
: "My Timesheets this month"

, "My Timesheets last month"
: "My Timesheets last month"

, "Timeaccounts to bill"
: "Timeaccounts to bill"

, "Timeaccounts not yet billed"
: "Timeaccounts not yet billed"

, "Timeaccounts already billed"
: "Timeaccounts already billed"

, "Manage timeaccounts"
: "Manage timeaccounts"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Add, edit and delete timeaccounts (includes all timesheet grants)"

, "Add timeaccounts"
: "Add timeaccounts"

, "Manage shared timeaccount favorites"
: "Manage shared timeaccount favorites"

, "Create or update shared timeaccount favorites"
: "Create or update shared timeaccount favorites"

, "Manage shared timesheet favorites"
: "Manage shared timesheet favorites"

, "Create or update shared timesheet favorites"
: "Create or update shared timesheet favorites"

, "Timesheet"
: "Timesheet"

, "Timeaccount"
: "Timeaccount"

, "Time Account"
: "Time Account"

, "Timeaccount Grant"
: "Timeaccount Grant"

, "Delete {0}"
: "Delete {0}"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
